package com.caimei365.user.controller;

import com.caimei365.user.idempotent.Idempotent;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubOnlineDto;
import com.caimei365.user.model.dto.ClubRegisterDto;
import com.caimei365.user.model.dto.ClubUpgradeDto;
import com.caimei365.user.model.dto.ShopRegisterDto;
import com.caimei365.user.model.po.ClubPo;
import com.caimei365.user.model.po.ShopPo;
import com.caimei365.user.service.RegisterService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;


/**
 * 注册Api
 *
 * @author : Charles
 * @date : 2021/3/10
 */
@Api(tags="注册Api")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/register")
public class RegisterApi {
    private final RegisterService registerService;

    /**
     * 普通机构入驻(注册)
     *
     * spi旧接口：/club/common
     *
     * @param clubRegisterDto ClubRegisterDto{
     *                          source            注册来源: 0网站 1小程序
     *                          userName          用户名
     *                          bindMobile        企业绑定手机号
     *                          password          密码
     *                          unionId           微信unionId
     *                          nickName          微信昵称
     *                          avatarUrl         微信头像(旧：headimgurl)
     *                        }
     * @param passWordConfirm 用户确认密码
     * @param smsCode         短信验证码(旧：activationCode)
     * @param isAgreed        是否同意勾选同意协议，1是，其他否
     * @param headers         HttpHeaders
     * @return ClubPo
     */
    @ApiOperation("注册普通机构")
    @Idempotent(prefix="idempotent_club", keys={"#baseUser"}, expire=5)
    @PostMapping("/club")
    public ResponseJson clubRegister(
        ClubRegisterDto clubRegisterDto,
        @ApiParam(required = true, value = "用户确认密码") @RequestParam("passWordConfirm") String passWordConfirm,
        @ApiParam(required = true, value = "短信验证码") @RequestParam("smsCode") String smsCode,
        @ApiParam(required = true, value = "是否同意勾选同意协议，1是，其他否") @RequestParam("isAgreed") Integer isAgreed,
        @RequestHeader HttpHeaders headers
    ) {
        return registerService.clubRegister(clubRegisterDto, passWordConfirm, smsCode, isAgreed, headers);
    }

    /**
     * 普通机构升级会员机构
     *
     * spi旧接口：/club/upgrade
     *
     * @param upgradeDto ClubUpgradeDto:{
     *                      clubId                 机构ID
     *                      userId                 用户ID
     *                      name                   机构名称
     *                      sName                  机构简称
     *                      contractEmail          邮箱（contractEmail1）
     *                      contractPhone          固定电话
     *                      linkMan                联系人（linkMan1）
     *                      provinceId             省Id
     *                      cityId                 市Id
     *                      townId                 县区Id
     *                      address                地址
     *                      shopPhoto              门头照(headpic)
     *                      businessLicense        营业执照（businessLicenseImage）
     *                      socialCreditCode       统一社会信用代码（socialCreditCode）
     *                      firstClubType          一级分类：医美=1和生美=2
     *                      secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *                      department             医美分类下的门诊和医院则需要填写科室
     *                      medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *                      mainProduct            主打项目（mainpro）
     *                      fax                    传真
     *                      profile                公司简介
     *                  }
     * @param headers   HttpHeaders
     * @return ClubPo
     */
    @ApiOperation("普通机构升级会员机构")
    @PostMapping("/club/upgrade")
    public ResponseJson clubUpgrade(
        ClubUpgradeDto upgradeDto,
        @RequestHeader HttpHeaders headers
    ){
        return registerService.clubUpgrade(upgradeDto, headers);
    }

    /**
     * 协销拉机构上线
     *
     * spi旧接口：/seller/club/register
     *
     * @param onlineDto ClubOnlineDto:{
     *                  source                  注册来源: 0网站 1小程序
     *                  userId                  协销用户ID(userID)
     *                  name                    机构名称
     *                  sName                   机构简称(sname)
     *                  bindMobile              企业绑定手机号
     *                  contractEmail           邮箱（email）
     *                  linkMan                 联系人（linkMan1）
     *                  provinceId             省Id
     *                  cityId                 市Id
     *                  townId                 县区Id
     *                  address                地址
     *                  shopPhoto              门头照(headpic)
     *                  businessLicense        营业执照（businessLicenseImage）
     *                  socialCreditCode       统一社会信用代码（socialCreditCode）
     *                  firstClubType          一级分类：医美=1和生美=2
     *                  secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *                  department             医美分类下的门诊和医院则需要填写科室
     *                  medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *                  mainProduct            主打项目（mainpro）
     *                  }
     * @param isAgreed  是否同意勾选同意协议，1是，其他否
     * @param headers   HttpHeaders
     * @return ClubPo
     */
    @ApiOperation("协销拉机构上线（机构注册）")
    @PostMapping("/club/online")
    public ResponseJson<ClubPo> clubOnline(
        ClubOnlineDto onlineDto,
        @ApiParam("是否同意勾选同意协议，1是，其他否") @RequestParam("isAgreed") Integer isAgreed,
        @RequestHeader HttpHeaders headers
    ) {
        return registerService.clubOnline(onlineDto, isAgreed, headers);
    }

    /**
     * 小程序端分步供应商注册
     *
     * spi旧接口：supplier/appletsRegistered
     *
     * @param shopRegisterDto ShopRegisterDto{
     *                        source                注册来源: 0网站 1小程序
     *                        name                  组织名称
     *                        sName                 供应商公司简称(sname)
     *                        bindMobile            企业绑定手机号
     *                        email                 邮箱
     *                        password              密码
     *                        linkMan               联系人
     *                        provinceId            省(provinceID)
     *                        cityId                市(cityID)
     *                        townId                所在县区Id(townID)
     *                        address               地址
     *                        socialCreditCode      统一社会信用代码
     *                        businessLicense       营业执照(businessLicenseImage)
     *                        firstShopType         医疗=1和非医疗=2
     *                        secondShopType        医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     *                        mainProduct           主打项目(mainpro)
     *                    }
     * @param passWordConfirm 用户确认密码
     * @param smsCode         短信验证码(旧：activationCode)
     * @param isAgreed        是否同意勾选同意协议，1是，其他否
     * @param whichStep       注册步数: PC(0)，小程序(1,2,3)
     * @param headers         HttpHeaders
     * @return ShopPo
     */
    @ApiOperation("供应商注册")
    @Idempotent(prefix="idempotent_shop", keys={"#shopRegisterDto"}, expire=5)
    @PostMapping("/shop/applets")
    public ResponseJson<ShopPo> shopRegister(
        ShopRegisterDto shopRegisterDto,
        @ApiParam("用户确认密码") @RequestParam("passWordConfirm") String passWordConfirm,
        @ApiParam("短信验证码") @RequestParam("smsCode") String smsCode,
        @ApiParam("是否同意勾选同意协议，1是，其他否") @RequestParam("isAgreed") Integer isAgreed,
        @ApiParam("注册步数: PC(0)，小程序(1,2,3)") @RequestParam("whichStep") Integer whichStep,
        @RequestHeader HttpHeaders headers
    ) {
        return registerService.shopRegister(shopRegisterDto, passWordConfirm, smsCode, isAgreed, whichStep, headers);
    }


}



